# ComicConverter

![Github Actions Status](https://github.com/tho121/ComicConverter/workflows/Build/badge.svg)[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/tho121/ComicConverter/master?urlpath=lab)

Daye Kang's implementation for converting JupyterLab notebooks into a data comic for CHI 2021



## Requirements

* JupyterLab >= 3.0

## Install

```bash
pip install ComicConverter
```

### Uninstall

```bash
pip uninstall ComicConverter
```
